@@ -28,6 +28,7 @@ class Aws(VaultApiBase):
         sts_endpoint=None,
         iam_server_id_header_value=None,
         mount_point=AWS_DEFAULT_MOUNT_POINT,
+        sts_region=None,
     ):
         """Configure the credentials required to perform API calls to AWS as well as custom endpoints to talk to AWS API.
 
@@ -69,6 +70,9 @@ class Aws(VaultApiBase):
         :type iam_server_id_header_value: str | unicode
         :param mount_point: The path the AWS auth method was mounted on.
         :type mount_point: str | unicode
+        :param sts_region: Region to override the default region for making AWS STS API calls. Should only be set if
+            sts_endpoint is set. If so, should be set to the region in which the custom sts_endpoint resides
+        :type sts_region: str | unicode
         :return: The response of the request.
         :rtype: requests.Response
         """
@@ -82,6 +86,7 @@ class Aws(VaultApiBase):
                 "iam_endpoint": iam_endpoint,
                 "sts_endpoint": sts_endpoint,
                 "iam_server_id_header_value": iam_server_id_header_value,
+                "sts_region": sts_region,
             }
         )
         api_path = utils.format_url(
@@ -128,7 +133,12 @@ class Aws(VaultApiBase):
         return self._adapter.delete(url=api_path)
 
     def configure_identity_integration(
-        self, iam_alias=None, ec2_alias=None, mount_point=AWS_DEFAULT_MOUNT_POINT
+        self,
+        iam_alias=None,
+        ec2_alias=None,
+        mount_point=AWS_DEFAULT_MOUNT_POINT,
+        iam_metadata=None,
+        ec2_metadata=None,
     ):
         """Configure the way that Vault interacts with the Identity store.
 
@@ -146,34 +156,44 @@ class Aws(VaultApiBase):
             select full_arn and then delete and recreate the IAM role, Vault won't be aware and any identity aliases
             set up for the role name will still be valid
         :type iam_alias: str | unicode
+        :param iam_metadata: The metadata to include on the token returned by the login endpoint.
+            This metadata will be added to both audit logs, and on the ``iam_alias``. By default, it includes ``account_id``
+            and ``auth_type``. Additionally, ``canonical_arn``, ``client_arn``, ``client_user_id``, ``inferred_aws_region``, ``inferred_entity_id``,
+            and ``inferred_entity_type`` are available. To include no metadata, set to an empty list ``[]``.
+            To use only particular fields, select the explicit fields. To restore to defaults, send only a field of ``default``.
+            Only select fields that will have a low rate of change for your ``iam_alias`` because each change triggers a storage
+            write and can have a performance impact at scale.
+        :type iam_metadata: str | unicode | list
         :param ec2_alias: Configures how to generate the identity alias when using the ec2 auth method. Valid choices
             are role_id, instance_id, and image_id. When role_id is selected, the randomly generated ID of the role is
             used. When instance_id is selected, the instance identifier is used as the identity alias name. When
             image_id is selected, AMI ID of the instance is used as the identity alias name
         :type ec2_alias: str | unicode
+        :param ec2_metadata: The metadata to include on the token returned by the login endpoint. This metadata will be
+            added to both audit logs, and on the ``ec2_alias``. By default, it includes ``account_id`` and ``auth_type``. Additionally,
+            ``ami_id``, ``instance_id``, and ``region`` are available. To include no metadata, set to an empty list ``[]``.
+            To use only particular fields, select the explicit fields. To restore to defaults, send only a field of ``default``.
+            Only select fields that will have a low rate of change for your ``ec2_alias`` because each change triggers a storage
+            write and can have a performance impact at scale.
+        :type ec2_metadata: str | unicode | list
         :param mount_point: The path the AWS auth method was mounted on.
         :type mount_point: str | unicode
         :return: The response of the request
         :rtype: request.Response
         """
         if iam_alias is not None and iam_alias not in ALLOWED_IAM_ALIAS_TYPES:
-            error_msg = 'invalid iam alias type provided: "{arg}"; supported iam alias types: "{alias_types}"'
-            raise exceptions.ParamValidationError(
-                error_msg.format(
-                    arg=iam_alias, environments=",".join(ALLOWED_IAM_ALIAS_TYPES)
-                )
-            )
+            error_msg = f"invalid iam alias type provided: '{iam_alias}' - supported iam alias types: '{','.join(ALLOWED_IAM_ALIAS_TYPES)}'"
+            raise exceptions.ParamValidationError(error_msg)
         if ec2_alias is not None and ec2_alias not in ALLOWED_EC2_ALIAS_TYPES:
-            error_msg = 'invalid ec2 alias type provided: "{arg}"; supported ec2 alias types: "{alias_types}"'
-            raise exceptions.ParamValidationError(
-                error_msg.format(
-                    arg=ec2_alias, environments=",".join(ALLOWED_EC2_ALIAS_TYPES)
-                )
-            )
+            error_msg = f"invalid ec2 alias type provided: '{ec2_alias}' - supported ec2 alias types: '{','.join(ALLOWED_EC2_ALIAS_TYPES)}'"
+            raise exceptions.ParamValidationError(error_msg)
+
         params = utils.remove_nones(
             {
                 "iam_alias": iam_alias,
                 "ec2_alias": ec2_alias,
+                "ec2_metadata": ec2_metadata,
+                "iam_metadata": iam_metadata,
             }
         )
         api_auth = "/v1/auth/{mount_point}/config/identity".format(
